__title__ = 'requests-raw'
__description__ = 'Use requests to talk HTTP via a Raw sockets (To Test RFC Compliance)'
__url__ = 'https://github.com/realgam3/requests-raw'
__version__ = '1.0.0'
__build__ = 0x010000
__author__ = 'Tomer Zait (realgam3)'
__author_email__ = 'realgam3@gmail.com'
__license__ = 'Apache 2.0'
__copyright__ = 'Copyright 2020 Tomer Zait'
